==> ydb-proto-api-1.5.0-sources.jar: tech/ydb/proto/federation/discovery/v1/FederationDiscoveryServiceGrpc.java <==
package tech.ydb.proto.federation.discovery.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.43.2)",
    comments = "Source: ydb_federation_discovery_v1.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class FederationDiscoveryServiceGrpc {

  private FederationDiscoveryServiceGrpc() {}

  public static final String SERVICE_NAME = "Ydb.FederationDiscovery.V1.FederationDiscoveryService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest,
      tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> getListFederationDatabasesMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "ListFederationDatabases",
      requestType = tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest.class,
      responseType = tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest,
      tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> getListFederationDatabasesMethod() {
    io.grpc.MethodDescriptor<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest, tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> getListFederationDatabasesMethod;
    if ((getListFederationDatabasesMethod = FederationDiscoveryServiceGrpc.getListFederationDatabasesMethod) == null) {
      synchronized (FederationDiscoveryServiceGrpc.class) {
        if ((getListFederationDatabasesMethod = FederationDiscoveryServiceGrpc.getListFederationDatabasesMethod) == null) {
          FederationDiscoveryServiceGrpc.getListFederationDatabasesMethod = getListFederationDatabasesMethod =
              io.grpc.MethodDescriptor.<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest, tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "ListFederationDatabases"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse.getDefaultInstance()))
              .setSchemaDescriptor(new FederationDiscoveryServiceMethodDescriptorSupplier("ListFederationDatabases"))
              .build();
        }
      }
    }
    return getListFederationDatabasesMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static FederationDiscoveryServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceStub>() {
        @java.lang.Override
        public FederationDiscoveryServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new FederationDiscoveryServiceStub(channel, callOptions);
        }
      };
    return FederationDiscoveryServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static FederationDiscoveryServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceBlockingStub>() {
        @java.lang.Override
        public FederationDiscoveryServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new FederationDiscoveryServiceBlockingStub(channel, callOptions);
        }
      };
    return FederationDiscoveryServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static FederationDiscoveryServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceFutureStub>() {
        @java.lang.Override
        public FederationDiscoveryServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new FederationDiscoveryServiceFutureStub(channel, callOptions);
        }
      };
    return FederationDiscoveryServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class FederationDiscoveryServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public void listFederationDatabases(tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request,
        io.grpc.stub.StreamObserver<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getListFederationDatabasesMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getListFederationDatabasesMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest,
                tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse>(
                  this, METHODID_LIST_FEDERATION_DATABASES)))
          .build();
    }
  }

  /**
   */
  public static final class FederationDiscoveryServiceStub extends io.grpc.stub.AbstractAsyncStub<FederationDiscoveryServiceStub> {
    private FederationDiscoveryServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FederationDiscoveryServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new FederationDiscoveryServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public void listFederationDatabases(tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request,
        io.grpc.stub.StreamObserver<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getListFederationDatabasesMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class FederationDiscoveryServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<FederationDiscoveryServiceBlockingStub> {
    private FederationDiscoveryServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FederationDiscoveryServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new FederationDiscoveryServiceBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse listFederationDatabases(tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getListFederationDatabasesMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class FederationDiscoveryServiceFutureStub extends io.grpc.stub.AbstractFutureStub<FederationDiscoveryServiceFutureStub> {
    private FederationDiscoveryServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FederationDiscoveryServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new FederationDiscoveryServiceFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> listFederationDatabases(
        tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getListFederationDatabasesMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_LIST_FEDERATION_DATABASES = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final FederationDiscoveryServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(FederationDiscoveryServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_LIST_FEDERATION_DATABASES:
          serviceImpl.listFederationDatabases((tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest) request,
              (io.grpc.stub.StreamObserver<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class FederationDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    FederationDiscoveryServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return tech.ydb.proto.federation.discovery.v1.YdbFederationDiscoveryV1.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("FederationDiscoveryService");
    }
  }

  private static final class FederationDiscoveryServiceFileDescriptorSupplier
      extends FederationDiscoveryServiceBaseDescriptorSupplier {
    FederationDiscoveryServiceFileDescriptorSupplier() {}
  }

  private static final class FederationDiscoveryServiceMethodDescriptorSupplier
      extends FederationDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    FederationDiscoveryServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (FederationDiscoveryServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new FederationDiscoveryServiceFileDescriptorSupplier())
              .addMethod(getListFederationDatabasesMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> ydb-proto-api-1.6.0-sources.jar: tech/ydb/proto/federation/discovery/v1/FederationDiscoveryServiceGrpc.java <==
package tech.ydb.proto.federation.discovery.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.59.1)",
    comments = "Source: ydb_federation_discovery_v1.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class FederationDiscoveryServiceGrpc {

  private FederationDiscoveryServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "Ydb.FederationDiscovery.V1.FederationDiscoveryService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest,
      tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> getListFederationDatabasesMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "ListFederationDatabases",
      requestType = tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest.class,
      responseType = tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest,
      tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> getListFederationDatabasesMethod() {
    io.grpc.MethodDescriptor<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest, tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> getListFederationDatabasesMethod;
    if ((getListFederationDatabasesMethod = FederationDiscoveryServiceGrpc.getListFederationDatabasesMethod) == null) {
      synchronized (FederationDiscoveryServiceGrpc.class) {
        if ((getListFederationDatabasesMethod = FederationDiscoveryServiceGrpc.getListFederationDatabasesMethod) == null) {
          FederationDiscoveryServiceGrpc.getListFederationDatabasesMethod = getListFederationDatabasesMethod =
              io.grpc.MethodDescriptor.<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest, tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "ListFederationDatabases"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse.getDefaultInstance()))
              .setSchemaDescriptor(new FederationDiscoveryServiceMethodDescriptorSupplier("ListFederationDatabases"))
              .build();
        }
      }
    }
    return getListFederationDatabasesMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static FederationDiscoveryServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceStub>() {
        @java.lang.Override
        public FederationDiscoveryServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new FederationDiscoveryServiceStub(channel, callOptions);
        }
      };
    return FederationDiscoveryServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static FederationDiscoveryServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceBlockingStub>() {
        @java.lang.Override
        public FederationDiscoveryServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new FederationDiscoveryServiceBlockingStub(channel, callOptions);
        }
      };
    return FederationDiscoveryServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static FederationDiscoveryServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<FederationDiscoveryServiceFutureStub>() {
        @java.lang.Override
        public FederationDiscoveryServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new FederationDiscoveryServiceFutureStub(channel, callOptions);
        }
      };
    return FederationDiscoveryServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    default void listFederationDatabases(tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request,
        io.grpc.stub.StreamObserver<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getListFederationDatabasesMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service FederationDiscoveryService.
   */
  public static abstract class FederationDiscoveryServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return FederationDiscoveryServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service FederationDiscoveryService.
   */
  public static final class FederationDiscoveryServiceStub
      extends io.grpc.stub.AbstractAsyncStub<FederationDiscoveryServiceStub> {
    private FederationDiscoveryServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FederationDiscoveryServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new FederationDiscoveryServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public void listFederationDatabases(tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request,
        io.grpc.stub.StreamObserver<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getListFederationDatabasesMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service FederationDiscoveryService.
   */
  public static final class FederationDiscoveryServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<FederationDiscoveryServiceBlockingStub> {
    private FederationDiscoveryServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FederationDiscoveryServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new FederationDiscoveryServiceBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse listFederationDatabases(tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getListFederationDatabasesMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service FederationDiscoveryService.
   */
  public static final class FederationDiscoveryServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<FederationDiscoveryServiceFutureStub> {
    private FederationDiscoveryServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FederationDiscoveryServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new FederationDiscoveryServiceFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Get list of databases.
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse> listFederationDatabases(
        tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getListFederationDatabasesMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_LIST_FEDERATION_DATABASES = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_LIST_FEDERATION_DATABASES:
          serviceImpl.listFederationDatabases((tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest) request,
              (io.grpc.stub.StreamObserver<tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getListFederationDatabasesMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesRequest,
              tech.ydb.proto.federation.discovery.FederationDiscoveryProtos.ListFederationDatabasesResponse>(
                service, METHODID_LIST_FEDERATION_DATABASES)))
        .build();
  }

  private static abstract class FederationDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    FederationDiscoveryServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return tech.ydb.proto.federation.discovery.v1.YdbFederationDiscoveryV1.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("FederationDiscoveryService");
    }
  }

  private static final class FederationDiscoveryServiceFileDescriptorSupplier
      extends FederationDiscoveryServiceBaseDescriptorSupplier {
    FederationDiscoveryServiceFileDescriptorSupplier() {}
  }

  private static final class FederationDiscoveryServiceMethodDescriptorSupplier
      extends FederationDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    FederationDiscoveryServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (FederationDiscoveryServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new FederationDiscoveryServiceFileDescriptorSupplier())
              .addMethod(getListFederationDatabasesMethod())
              .build();
        }
      }
    }
    return result;
  }
}
